==> coretoppings-4.1.0.tar.gz: coretoppings-v4.1.0/leave/leave.h <==
/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#pragma once

#include <QWidget>
#include <cprime/cplugininterface.h>

QT_BEGIN_NAMESPACE
namespace Ui { class leave; }
QT_END_NAMESPACE

class leave : public QWidget
{
    Q_OBJECT

public:
    leave(QWidget *parent = nullptr);
    ~leave();

private slots:
    void on_toolButton_lockscreen_clicked();
    void on_toolButton_logout_clicked();
    void on_toolButton_suspend_clicked();
    void on_toolButton_poweroff_clicked();
    void on_toolButton_reboot_clicked();
    void on_toolButton_hibernate_clicked();
    void on_toolButton_rebbotuefi_clicked();
    void on_toolButton_hybridsleep_clicked();
    void on_toolButton_suspenthenhibernate_clicked();

private:
    Ui::leave *ui;
};

class leavePlugin : public plugininterface {

    Q_OBJECT

    Q_PLUGIN_METADATA(IID COREACTION_PLUGININTERFACE)
    Q_INTERFACES(plugininterface)

public:
    /* Name of the plugin */
    QString name();

    /* The plugin version */
    QString version();

    /* The Widget */
    QWidget *widget(QWidget *);
};

==> coretoppings-v4.2.0.tar.gz: coretoppings-v4.2.0/leave/leave.h <==
/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for C Suite.
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#pragma once

#include <QWidget>
#include <cprime/cplugininterface.h>

QT_BEGIN_NAMESPACE
namespace Ui { class leave; }
QT_END_NAMESPACE

class leave : public QWidget
{
    Q_OBJECT

public:
    leave(QWidget *parent = nullptr);
    ~leave();

private slots:
    void on_toolButton_lockscreen_clicked();
    void on_toolButton_logout_clicked();
    void on_toolButton_suspend_clicked();
    void on_toolButton_poweroff_clicked();
    void on_toolButton_reboot_clicked();
    void on_toolButton_hibernate_clicked();
    void on_toolButton_rebbotuefi_clicked();
    void on_toolButton_hybridsleep_clicked();
    void on_toolButton_suspenthenhibernate_clicked();

private:
    Ui::leave *ui;
};

class leavePlugin : public WidgetsInterface {

    Q_OBJECT

    Q_PLUGIN_METADATA(IID WIDGETS_PLUGININTERFACE)
    Q_INTERFACES(WidgetsInterface)

public:
    /* Name of the plugin */
    QString name();

    /* The plugin version */
    QString version();

    /* The Widget */
    QWidget *widget(QWidget *);
};
